黑客帝国2：重装上阵 (豆瓣)
Description: 黑客帝国2：重装上阵电影简介和剧情介绍,黑客帝国2：重装上阵影评、图片、预告片、影讯、论坛、在线购票
Keywords: 黑客帝国2：重装上阵,The Matrix Reloaded,黑客帝国2：重装上阵影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.228豆瓣电影Top250

# 黑客帝国2：重装上阵 The Matrix Reloaded (2003)

导演: 拉娜·沃卓斯基 / 莉莉·沃卓斯基
编剧: 莉莉·沃卓斯基 / 拉娜·沃卓斯基
主演: 基努·里维斯 / 劳伦斯·菲什伯恩 / 凯瑞-安·莫斯 / 雨果·维文 / 莫妮卡·贝鲁奇 / 赫尔穆特·巴凯蒂斯 / 斯蒂夫·巴什托尼 / 克里斯汀·阿努 / 丹尼尔·伯哈特 / 约瑟芬·白内斯 / 安迪·阿尼斯 / 贾达·萍克·史密斯 / 邹兆龙 / 埃茜·戴维斯 / 纳许·埃哲顿 / 格洛丽亚·福斯特 / 大卫·富兰克林 / 诺娜·加耶 / 小罗伊·琼斯 / 大卫·基尔德 / 兰德尔·杜克·金 / 克里斯托弗·卡比 / 纳撒尼尔·利斯 / 哈里·列尼斯 / 罗伯特·马莫内 / 马特·麦科姆 / 罗宾·奈文 / 大卫·诺 / 吉娜薇·欧瑞丽 / 苏格拉底·奥图 / 哈罗德·佩里诺 / 阿德里安·雷梅特 / 尼尔·雷梅特 / 鲁伯特·雷德 / 大卫·罗伯茨 / 凯文·斯科特 / 尼坎德罗·托马斯 / 吉娜·托瑞斯 / 史蒂夫·维拉 / 克莱顿·华生 / 康奈尔·韦斯特 / 雷·沃纳尔 / 伯纳德·怀特 / 朗贝尔·维尔森 / 安东尼·布兰登·黄 / 安东尼·泽比
类型: 动作 / 科幻
制片国家/地区: 美国
语言: 英语 / 法语
上映日期: 2003-07-18(中国大陆) / 2003-05-07(韦斯特伍德首映) / 2003-05-15(美国)
片长: 138分钟
又名: 22世纪杀人网络2：决战未来(港) / 骇客任务：重装上阵(台) / 廿二世纪杀人网络2：决战未来 / 黑客帝国2 / 骇客帝国2
IMDb: tt0234215
豆瓣评分
引用
8.7
386514人评价
5星
46.7%
4星
41.1%
3星
11.2%
2星
0.8%
1星
0.2%
好于 98% 科幻片
好于 98% 动作片
想看 看过
评价:
推荐

## 黑客帝国2：重装上阵的剧情简介 · · · · · ·

上一部结尾，尼奥（基奴李维斯 饰）终于意识到自己的能力和使命，中弹复活后，变成了无所不能的“救世主”，他和女友崔妮蒂（凯莉·安·摩丝 饰），舰长墨菲斯（劳伦斯·菲什伯恩 饰）回到了人类的基地锡安，受到人们的热烈欢迎。
此时，“母体”决定先下手为强，派出了两万五千只电子乌贼攻击锡安基地；墨菲斯、尼奥和崔妮蒂则再次进入“母体”，寻找“制钥者”，准备从内部破坏；而本该被尼奥消灭的特勤史密斯似乎出了点问题，脱离了“母体”的控制，拥有可怕的复制能力，阻碍尼奥他们的行动。 ©豆瓣

## 黑客帝国2：重装上阵的演职员 · · · · · · ( 全部 187 )

- 拉娜·沃卓斯基 导演
- 莉莉·沃卓斯基 导演
- 基努·里维斯 饰 Neo
- 劳伦斯·菲什伯恩 饰 Morpheus
- 凯瑞-安·莫斯 饰 Trinity
- 雨果·维文 饰 Agent Smith

## 黑客帝国2：重装上阵的视频和图片 · · · · · · ( 预告片1 | 添加视频评论 | 图片1029 · 添加 )

## 喜欢这部电影的人也喜欢 · · · · · ·

  黑客帝国3：矩阵革命

  终结者2：审判日

  我，机器人

  变形金刚

  钢铁侠

  阿凡达

  第九区

  我是传奇

  2001太空漫游

  回到未来

我要写短评

## 黑客帝国2：重装上阵的短评 · · · · · · ( 全部 46297 条 )

热门 / 最新 / 好友

### 1286 有用 葱 看过 2012-05-23 00:05:52

剧情都在后20分钟，前面一大段都在不停地打打打打打打打，每一段打斗剧情结束我都会想不起来他们怎么会打到一起去的……

### 926 有用 朝暮雪 看过 2012-08-18 01:26:27

《黑客帝国1》还比较容易看懂，《黑客帝国2》《黑客帝国3》就很深奥了。 造物主（Architect）负责维持母体的平衡，先知则负责引导母体中的人们觉醒。 两个人的共同作用下，母体中的人类社会稳定进化，机器人也从中吸取经验。 这也是机器人“种植”人类的终极目的，并不仅仅是用人类发电，更是为了学习人类，从而实现进化。 锡安之所以存在，也是机器人故意让它存在。 机器人无法避免母体出现bug（也就是有人觉... 《黑客帝国1》还比较容易看懂，《黑客帝国2》《黑客帝国3》就很深奥了。 造物主（Architect）负责维持母体的平衡，先知则负责引导母体中的人们觉醒。 两个人的共同作用下，母体中的人类社会稳定进化，机器人也从中吸取经验。 这也是机器人“种植”人类的终极目的，并不仅仅是用人类发电，更是为了学习人类，从而实现进化。 锡安之所以存在，也是机器人故意让它存在。 机器人无法避免母体出现bug（也就是有人觉醒），所以就等他们觉醒、等他们组建反抗军。 机器人每隔一段时间就来一次大清洗，把反抗军歼灭，然后再把母体重启。 这种大清洗已经进行过5次了，这是第6次了。 前5次的结局都是反抗军全军覆没，母体重启，而尼奥的出现让世界首次出现了不同的结局——和平。 人类和机器人互利共生，共同进化。 但是这种和平又能维持多久呢？ (展开)

### 680 有用 Arthur 看过 2012-10-07 17:32:33

强烈建议3D重映！各种视效爆炸飞到脸上，就是为3D而生的。黑人文化、中国功夫和后现代机械感硬凑到一起，真是敢弄。一千个雨果大额头让功夫相形见绌，里维斯衣服好娘，白老头黑姨妈真般配。就是动作戏实在多过了头

### 383 有用 沙尾一姐小渡边 看过 2016-01-21 22:23:34

第一部对现实说的很清楚了，第二部就让我们见识一下，这些发现真相的人类会怎么做。最精彩的莫过于里面Neo和先知的对白了，解释了宇宙、自然和社会的现象。其实这里有一个伏笔，那就是程序的命运和终点。真实世界与虚拟世界是共通的，电影在让主角们努力拯救自己的家园的同时，也在探讨这一点：万物运转的规律。神仙其实只是一个程序，外星人和妖魔鬼怪只是系统出了bug

### 398 有用 Karuto 看过 2020-04-09 13:58:23

第一部故事讲得太优秀太完整了，而且暗地里留了那么多可以延伸的线头，剧组选择了两个：从时间上延伸——救世主不是唯一的，尼奥经历的已是第六次人类补完计划；从空间上延伸——引入锡安和机械城这两个大终端。前者很成功，后者挺失败。全片主旨总结下来，其实只要三段对话就够了：在锡安深夜和议长聊；在院子里和先知聊；最后和建筑师聊。中间打了一个漫长的法国佬副本，匆促、媚俗、无聊。建筑师那段我隔了十几年才看明白：尼奥... 第一部故事讲得太优秀太完整了，而且暗地里留了那么多可以延伸的线头，剧组选择了两个：从时间上延伸——救世主不是唯一的，尼奥经历的已是第六次人类补完计划；从空间上延伸——引入锡安和机械城这两个大终端。前者很成功，后者挺失败。全片主旨总结下来，其实只要三段对话就够了：在锡安深夜和议长聊；在院子里和先知聊；最后和建筑师聊。中间打了一个漫长的法国佬副本，匆促、媚俗、无聊。建筑师那段我隔了十几年才看明白：尼奥做出的选择不是「救妹子」，而是通过拒绝背人类补完计划的锅，选择了代表着自由意志的「选择」本身。 (展开)

> 更多短评 46297条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 黑客帝国2：重装上阵的影评 · · · · · · ( 全部 241 条 )

热门 / 最新 / 好友
Ankie 2011-01-03 21:40:30

## 《黑客帝国》:一个深邃的虚拟真实世界，一部伟大的科幻史诗!

这篇影评可能有剧透

《黑客帝国》——创造了一个深邃的虚拟真实世界，一部伟大的科幻史诗! 　　本文根据《The Matrix I，II，III》，《AniMatrix》以及众多黑客网友的讨论，整理消化总结而来，向“虚拟世界”的各位网友致敬。 　　（一）背景 　　起初，神创造了人。此处呼应《圣经》，因为人的祖... (展开)
1496 41 112回应 收起
Mr.Child 2017-04-22 11:28:14

## 没看懂太正常了，你需要脑补一点佛教的世界观

这篇影评可能有剧透

1999年，首部《黑客帝国》上映， 这部片子颠覆了很多人的世界观。 许多人从不同维度解释，发现其实都是有漏洞。 特别是第二部，第三部越看越糊涂。 为什么Neo面对机器乌贼有超能力， 为什么第6代救世主能拯救锡安， 电脑和人类社会的关系到底什么... 如今回忆起来，我越来... (展开)
1094 29 107回应 收起
shirla 2012-02-15 16:21:34

## Neo与Architect的对话

这篇影评可能有剧透

The Architect - Hello, Neo. 建造者：你好，Neo。 Neo - Who are you? Neo：你是谁？ The Architect - I am the Architect. I created the matrix. I've been waiting for you. You have many questions, and although the process has altered your consciousness, you ... (展开)
256 12 32回应 收起
Neo 2019-04-08 23:09:39

## 《黑客帝国系列》之百遍观感II：进化实验

这篇影评可能有剧透

本系列影评，共计三篇，本篇为第二篇，这里留下其他两篇的链接，一起食用，相信会效果更佳~ 《黑客帝国》的豆瓣影评:【《黑客帝国系列》之百遍观感I：终极解答】 https://www.douban.com/doubanapp/dispatch/review/10077344 《黑客帝国2：重装上阵》的豆瓣影评:【《黑客帝国系... (展开)
226 2 73回应 收起
墨梓 2011-10-14 12:09:00

## 重温黑客帝国三部曲+动画版后，我对这部电影的看法（剧情篇）

这篇影评可能有剧透

首先要膜拜下沃卓斯基二人，在当时就能够建立如此庞大的世界观以及拥有如此的远见，虽说机器文明取代人类文明的电影也曾有过（比如终结者），但是黑客帝国这部电影的全局观更加庞大以及毫无漏洞。在看过很多人的影评后也写下自己对于这部神作的一点看法。 背景：人类科技在不断... (展开)
154 2 21回应 收起
止轩 2011-07-02 12:26:25

## 整部电影的【真正的】潜台词~~~

这篇影评可能有剧透

我不想评述1和3。但是就仅仅对黑客帝国2而言。我发现很多写影评的人 其实并没有看懂。 这部电影的真正最核心的思想是： 量子物理选择性 与 经典物理的因果律之争。 这话要从1927年的第五届索尔维会议说起。 这场科学史上的大论战的核心人物就是 爱因斯坦和波尔。 爱因... (展开)
249 90 41回应 收起
四月物语 2010-08-16 11:14:45

## 电影《黑客帝国2：重装上阵》中的革新技术，虚拟拍摄与视觉预览，Virtual Cinematography & Pre-Visualization

摘自《新电影》第20期。 在《黑客帝国2：重装上阵》中，沃卓斯基兄弟和视觉总监约翰·吉塔抛弃费时费力的“子弹时间”，在电影历史上第一次使用全面的“虚拟拍摄技术”。 所谓“虚拟拍摄”指的的是把一个真实世界和演员“全息”复制，克隆到电脑里的虚幻世界，从而在物理意义上... (展开)
51 4 3回应 收起
菜刀暗夜独行 2008-05-27 19:01:02

## 浮出水面的黑客帝国

嘿嘿，本人科学知识有限，因此无意对黑客的某些艰深的理论作深入探讨，只想谈谈它的外在的一些东西。正如一座冰山，隐藏在水下的是它的主体部分，浮出水面的只是它的一小部分。这正是文章起这么一个题目的原因。 一、 任何知识派系的构成，都是先假设某些东西成立，然后基于这... (展开)
84 25 8回应 收起
rickcafe 2016-07-02 12:54:56

## 《黑客帝国2》中的5段台词

这篇影评可能有剧透

《黑客帝国》三部曲中1最经典，艺术和思想俱佳，全片一气呵成，浑然天成，不留任何尿点；3稍次，视觉效果不错，雨中大战，锡安保卫战场面震撼；2最差，故事冗长拖沓，情节混乱不堪，出场人物众多，表演夸张欠火候，大量情节可有可无，很多人看完2是一头雾水，不知所云。 但要... (展开)
71 5 8回应 收起
薛定谔的猫 2015-11-06 20:41:47

## 技术为电影插上翅膀

电影作为一种特殊的艺术，它的每一次飞跃都离不开科技的进步与发展，而电影人对现有技术的大胆革新又推动了科技的新发展。可以说，《黑客帝国》的成功在很大程度上是借助了当时最先进的数字技术，而幕后团队富有想像力的改造又为以后的电影提供了可能和范本。这是一种良性的循... (展开)
29 2 1回应 收起

> 更多影评 241篇

添加新讨论

## 讨论区 · · · · · ·

为什么绿代码里有日语？ | 来自爱松人🌛 | 8 回应 | 2022-10-19 15:28:55
好多你哥 | 来自连诺 |  | 2022-10-18 20:50:17
尼奥是不是为了女主放弃了zion？ | 来自Richhoul | 1 回应 | 2022-10-17 16:29:09
节奏慢到可以催眠，前面45分钟不知道你要讲啥。后... | 来自Hua | 17 回应 | 2022-10-13 12:06:03
关于墨镜的细节说明什么？ | 来自明朗的冬天 |  | 2022-10-10 21:36:32

> 去这部影片的讨论区（全部97条）

## 关于《黑客帝国2：重装上阵》的问题 · · · · · · ( 全部11个 )

- 对武打很不解 明明很厉害的人 老是耍太极？ 7人回答
- 史密斯是怎么控制锡恩叛徒的？改变人的思维 这个不合理吧？ 2人回答

> 全部11个问题

## 本片原声正在播放 · · · · · ·

去豆瓣音乐收听

## 以下片单推荐 · · · · · · ( 全部 )

- ★豆瓣高分电影榜★ （上）9.7-8.6分 (影志)
- 入选《第十放映室》影片之国外篇Ⅰ (心之旋影)
- {北美电影票房总排行} (荔枝超人)
- IMDb科幻电影Top200 (等一个人)
- 带你进入不正常的世界 (DK小眼镜儿)

## 谁在看这部电影 · · · · · ·

- 凡尘
  9分钟前 看过
- 哈哈哈哈12305
  12分钟前 看过
- Joey
  12分钟前 看过

637576人看过 / 61127人想看

订阅黑客帝国2：重装上阵的评论:
feed: rss 2.0